@@ -41,3 +41,9 @@ class NativeMetricsManagementService(Service):
     @is_connected
     def hw_metrics_mgmt_service_get_metric(self, param_dict, **kwargs):
         return self._grpc_helper(self.stub.GetMetric, hw_metrics_mgmt_service_pb2.GetMetricRequest, param_dict, **kwargs)
+
+    # rpc StreamMetrics(google.protobuf.Empty) returns(stream Metric);
+    @keyword
+    @is_connected
+    def hw_metrics_mgmt_service_stream_metrics(self, **kwargs):
+        return self._grpc_helper(self.stub.StreamMetrics, **kwargs)
